@@ -58,7 +58,7 @@ pub fn solve(input: &mut Input) -> Result<String, String> {
 
 #[test]
 fn test() {
-    use crate::{test_part_one, test_part_two};
+    use crate::input::{test_part_one, test_part_two};
     let real_input = include_str!("day10_input.txt");
     test_part_one!(real_input => "62238".to_string());
     test_part_two!(real_input => "2b0c9cc0449507a0db3babd57ad9e8d8".to_string());
