@@ -1,6 +1,6 @@
 use super::int_code::Program;
 use super::int_code::Word;
-use crate::Input;
+use crate::input::Input;
 
 pub fn solve(input: &mut Input) -> Result<Word, String> {
     let mut program = Program::parse(input.text)?;
